@@ -12,11 +12,13 @@ package choose
 
 import (
 	"strings"
+	"time"
+
+	"github.com/charmbracelet/gum/timeout"
 
 	"github.com/charmbracelet/bubbles/paginator"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
-	"github.com/mattn/go-runewidth"
 )
 
 type model struct {
@@ -40,6 +42,8 @@ type model struct {
 	headerStyle       lipgloss.Style
 	itemStyle         lipgloss.Style
 	selectedItemStyle lipgloss.Style
+	hasTimeout        bool
+	timeout           time.Duration
 }
 
 type item struct {
@@ -48,13 +52,27 @@ type item struct {
 	order    int
 }
 
-func (m model) Init() tea.Cmd { return nil }
+func (m model) Init() tea.Cmd {
+	return timeout.Init(m.timeout, nil)
+}
 
 func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	switch msg := msg.(type) {
 	case tea.WindowSizeMsg:
 		return m, nil
-
+	case timeout.TickTimeoutMsg:
+		if msg.TimeoutValue <= 0 {
+			m.quitting = true
+			// If the user hasn't selected any items in a multi-select.
+			// Then we select the item that they have pressed enter on. If they
+			// have selected items, then we simply return them.
+			if m.numSelected < 1 {
+				m.items[m.index].selected = true
+			}
+			return m, tea.Quit
+		}
+		m.timeout = msg.TimeoutValue
+		return m, timeout.Tick(msg.TimeoutValue, msg.Data)
 	case tea.KeyMsg:
 		start, end := m.paginator.GetSliceBounds(len(m.items))
 		switch keypress := msg.String(); keypress {
@@ -152,17 +170,21 @@ func (m model) View() string {
 	}
 
 	var s strings.Builder
+	var timeoutStr string
 
 	start, end := m.paginator.GetSliceBounds(len(m.items))
 	for i, item := range m.items[start:end] {
 		if i == m.index%m.height {
 			s.WriteString(m.cursorStyle.Render(m.cursor))
 		} else {
-			s.WriteString(strings.Repeat(" ", runewidth.StringWidth(m.cursor)))
+			s.WriteString(strings.Repeat(" ", lipgloss.Width(m.cursor)))
 		}
 
 		if item.selected {
-			s.WriteString(m.selectedItemStyle.Render(m.selectedPrefix + item.text))
+			if m.hasTimeout {
+				timeoutStr = timeout.Str(m.timeout)
+			}
+			s.WriteString(m.selectedItemStyle.Render(m.selectedPrefix + item.text + timeoutStr))
 		} else if i == m.index%m.height {
 			s.WriteString(m.cursorStyle.Render(m.cursorPrefix + item.text))
 		} else {
