@@ -6,10 +6,11 @@ import (
 	"os"
 	"path/filepath"
 
+	"github.com/charmbracelet/gum/internal/exit"
+
 	"github.com/alecthomas/kong"
 	"github.com/charmbracelet/bubbles/filepicker"
 	tea "github.com/charmbracelet/bubbletea"
-	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/style"
 )
 
@@ -29,6 +30,7 @@ func (o Options) Run() error {
 	}
 
 	fp := filepicker.New()
+	fp.CurrentDirectory = path
 	fp.Path = path
 	fp.Height = o.Height
 	fp.AutoHeight = o.Height == 0
@@ -36,17 +38,21 @@ func (o Options) Run() error {
 	fp.DirAllowed = o.Directory
 	fp.FileAllowed = o.File
 	fp.ShowHidden = o.All
-	fp.Styles = filepicker.Styles{
-		Cursor:     o.CursorStyle.ToLipgloss(),
-		Symlink:    o.SymlinkStyle.ToLipgloss(),
-		Directory:  o.DirectoryStyle.ToLipgloss(),
-		File:       o.FileStyle.ToLipgloss(),
-		Permission: o.PermissionsStyle.ToLipgloss(),
-		Selected:   o.SelectedStyle.ToLipgloss(),
-		FileSize:   o.FileSizeStyle.ToLipgloss(),
-	}
+	fp.Styles = filepicker.DefaultStyles()
+	fp.Styles.Cursor = o.CursorStyle.ToLipgloss()
+	fp.Styles.Symlink = o.SymlinkStyle.ToLipgloss()
+	fp.Styles.Directory = o.DirectoryStyle.ToLipgloss()
+	fp.Styles.File = o.FileStyle.ToLipgloss()
+	fp.Styles.Permission = o.PermissionsStyle.ToLipgloss()
+	fp.Styles.Selected = o.SelectedStyle.ToLipgloss()
+	fp.Styles.FileSize = o.FileSizeStyle.ToLipgloss()
 
-	m := model{filepicker: fp}
+	m := model{
+		filepicker: fp,
+		timeout:    o.Timeout,
+		hasTimeout: o.Timeout > 0,
+		aborted:    false,
+	}
 
 	tm, err := tea.NewProgram(&m, tea.WithOutput(os.Stderr)).Run()
 	if err != nil {
