@@ -10,8 +10,10 @@ import (
 	"github.com/charmbracelet/bubbles/textinput"
 	"github.com/charmbracelet/bubbles/viewport"
 	tea "github.com/charmbracelet/bubbletea"
+	"github.com/mattn/go-isatty"
 	"github.com/sahilm/fuzzy"
 
+	"github.com/charmbracelet/gum/ansi"
 	"github.com/charmbracelet/gum/internal/exit"
 	"github.com/charmbracelet/gum/internal/files"
 	"github.com/charmbracelet/gum/internal/stdin"
@@ -82,11 +84,15 @@ func (o Options) Run() error {
 		matchStyle:            o.MatchStyle.ToLipgloss(),
 		headerStyle:           o.HeaderStyle.ToLipgloss(),
 		textStyle:             o.TextStyle.ToLipgloss(),
+		cursorTextStyle:       o.CursorTextStyle.ToLipgloss(),
 		height:                o.Height,
 		selected:              make(map[string]struct{}),
 		limit:                 o.Limit,
 		reverse:               o.Reverse,
 		fuzzy:                 o.Fuzzy,
+		timeout:               o.Timeout,
+		hasTimeout:            o.Timeout > 0,
+		sort:                  o.Sort,
 	}, options...)
 
 	tm, err := p.Run()
@@ -98,15 +104,19 @@ func (o Options) Run() error {
 		return exit.ErrAborted
 	}
 
+	isTTY := isatty.IsTerminal(os.Stdout.Fd())
+
 	// allSelections contains values only if limit is greater
 	// than 1 or if flag --no-limit is passed, hence there is
 	// no need to further checks
 	if len(m.selected) > 0 {
-		for k := range m.selected {
-			fmt.Println(k)
-		}
+		o.checkSelected(m, isTTY)
 	} else if len(m.matches) > m.cursor && m.cursor >= 0 {
-		fmt.Println(m.matches[m.cursor].Str)
+		if isTTY {
+			fmt.Println(m.matches[m.cursor].Str)
+		} else {
+			fmt.Println(ansi.Strip(m.matches[m.cursor].Str))
+		}
 	}
 
 	if !o.Strict && len(m.textinput.Value()) != 0 && len(m.matches) == 0 {
@@ -115,6 +125,16 @@ func (o Options) Run() error {
 	return nil
 }
 
+func (o Options) checkSelected(m model, isTTY bool) {
+	for k := range m.selected {
+		if isTTY {
+			fmt.Println(k)
+		} else {
+			fmt.Println(ansi.Strip(k))
+		}
+	}
+}
+
 // BeforeReset hook. Used to unclutter style flags.
 func (o Options) BeforeReset(ctx *kong.Context) error {
 	style.HideFlags(ctx)
