@@ -8,25 +8,35 @@
 package input
 
 import (
+	"time"
+
 	"github.com/charmbracelet/bubbles/textinput"
 	tea "github.com/charmbracelet/bubbletea"
+	"github.com/charmbracelet/gum/timeout"
 	"github.com/charmbracelet/lipgloss"
 )
 
 type model struct {
+	autoWidth   bool
 	header      string
 	headerStyle lipgloss.Style
 	textinput   textinput.Model
 	quitting    bool
 	aborted     bool
+	timeout     time.Duration
+	hasTimeout  bool
 }
 
-func (m model) Init() tea.Cmd { return textinput.Blink }
+func (m model) Init() tea.Cmd {
+	return tea.Batch(
+		textinput.Blink,
+		timeout.Init(m.timeout, nil),
+	)
+}
 func (m model) View() string {
 	if m.quitting {
 		return ""
 	}
-
 	if m.header != "" {
 		header := m.headerStyle.Render(m.header)
 		return lipgloss.JoinVertical(lipgloss.Left, header, m.textinput.View())
@@ -37,6 +47,18 @@ func (m model) View() string {
 
 func (m model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	switch msg := msg.(type) {
+	case timeout.TickTimeoutMsg:
+		if msg.TimeoutValue <= 0 {
+			m.quitting = true
+			m.aborted = true
+			return m, tea.Quit
+		}
+		m.timeout = msg.TimeoutValue
+		return m, timeout.Tick(msg.TimeoutValue, msg.Data)
+	case tea.WindowSizeMsg:
+		if m.autoWidth {
+			m.textinput.Width = msg.Width - lipgloss.Width(m.textinput.Prompt) - 1
+		}
 	case tea.KeyMsg:
 		switch msg.String() {
 		case "ctrl+c", "esc":
