@@ -10,13 +10,8 @@ import (
 
 // Read reads input from an stdin pipe.
 func Read() (string, error) {
-	stat, err := os.Stdin.Stat()
-	if err != nil {
-		return "", fmt.Errorf("failed to stat stdin: %w", err)
-	}
-
-	if stat.Mode()&os.ModeNamedPipe == 0 && stat.Size() == 0 {
-		return "", nil
+	if IsEmpty() {
+		return "", fmt.Errorf("stdin is empty")
 	}
 
 	reader := bufio.NewReader(os.Stdin)
@@ -35,3 +30,17 @@ func Read() (string, error) {
 
 	return b.String(), nil
 }
+
+// IsEmpty returns whether stdin is empty.
+func IsEmpty() bool {
+	stat, err := os.Stdin.Stat()
+	if err != nil {
+		return true
+	}
+
+	if stat.Mode()&os.ModeNamedPipe == 0 && stat.Size() == 0 {
+		return true
+	}
+
+	return false
+}
