@@ -32,12 +32,17 @@ func (o Options) Run() error {
 	}
 
 	model := model{
-		viewport:        vp,
-		helpStyle:       o.HelpStyle.ToLipgloss(),
-		content:         o.Content,
-		showLineNumbers: o.ShowLineNumbers,
-		lineNumberStyle: o.LineNumberStyle.ToLipgloss(),
-		softWrap:        o.SoftWrap,
+		viewport:            vp,
+		helpStyle:           o.HelpStyle.ToLipgloss(),
+		content:             o.Content,
+		origContent:         o.Content,
+		showLineNumbers:     o.ShowLineNumbers,
+		lineNumberStyle:     o.LineNumberStyle.ToLipgloss(),
+		softWrap:            o.SoftWrap,
+		matchStyle:          o.MatchStyle.ToLipgloss(),
+		matchHighlightStyle: o.MatchHighlightStyle.ToLipgloss(),
+		timeout:             o.Timeout,
+		hasTimeout:          o.Timeout > 0,
 	}
 	_, err := tea.NewProgram(model, tea.WithAltScreen()).Run()
 	if err != nil {
