@@ -8,8 +8,8 @@ type Options struct {
 	Columns       []string     `short:"c" help:"Column names"`
 	Widths        []int        `short:"w" help:"Column widths"`
 	Height        int          `help:"Table height" default:"10"`
-	CellStyle     style.Styles `embed:"" prefix:"cell." envprefix:"GUM_TABLE_CELL"`
-	HeaderStyle   style.Styles `embed:"" prefix:"header." envprefix:"GUM_TABLE_HEADER"`
-	SelectedStyle style.Styles `embed:"" prefix:"selected." set:"defaultForeground=212" envprefix:"GUM_TABLE_SELECTED"`
+	CellStyle     style.Styles `embed:"" prefix:"cell." envprefix:"GUM_TABLE_CELL_"`
+	HeaderStyle   style.Styles `embed:"" prefix:"header." envprefix:"GUM_TABLE_HEADER_"`
+	SelectedStyle style.Styles `embed:"" prefix:"selected." set:"defaultForeground=212" envprefix:"GUM_TABLE_SELECTED_"`
 	File          string       `short:"f" help:"file path" default:""`
 }
